Module user

Module user 

User-level paths in home directory

Constants

BIN_DIR
Binary installation directory
CREDENTIALS_FILE
Credentials file, relative to the user home directory.
MECHA10_DIR
Base mecha10 directory in user home.
TEMPLATES_DIR
Templates cache directory

Functions

bin
Get path to a binary in the mecha10 bin directory
bin_dir
Get the binary directory
cargo_bin
Get path to a binary in cargo bin directory
credentials_file
Get the credentials file path.
local_bin
Get path to a binary in local bin directory
mecha10_dir
Get the base mecha10 directory path
templates_dir
Get the templates cache directory